//
// main.c
//
// Color Orb Prototype 1.0
//
// This file contains code for the Microchip PIC10F200 for CCS PCM
//
// Copyright (c) 2006 Grand Idea Studio, Inc. (http://www.grandideastudio.com)
//

#include <10F200.h>
#use delay(clock=4000000)

// Configuration Bits:
// Watchdog Timer (WDT) = DISABLED
// Master Clear Enable = DISABLED (Functions as GP3)
// Code Protect = ENABLED
#fuses NOWDT, NOMCLR, PROTECT

#define LM4970_ADR				0b11110100
#define LM4970_MODE				0b00000100	// device power-up, enable audio synchronization randomizer
#define LM4970_FREQ				0b01000000  // PWM frequency = 15kHz, high pass filter cutoff frequency = 3.5kHz
#define LM4970_PATTERN			0b01100000  // LED driver controlled by audio synchronization
#define LM4970_PATTERN_TEST		0b01101111  // LED drivers controlled via I2C, all on (for testing)
#define LM4970_CURRENT			0b10111111  // maximum current drive setting per LED channel (2x, typical 42mA - less for audio sync mode)
#define LM4970_GAIN				0b11110100  // maximum audio gain (12dB), maximum midband audio filter gain

#define SW_TEST	 PIN_B3
#define I2C_SDA  PIN_B0
#define I2C_SCL  PIN_B1
#use i2c(master, sda=I2C_SDA, scl=I2C_SCL)

#ORG 0xA4, 0xDE
char const notice[] = {"(c) Grand Idea Studio, Inc. [www.grandideastudio.com]"};

#ORG 0xDF, 0xFF
char const revision[] = {"HW=1.0, SW=1.0, 04/10/2006"};

void send_i2c (char address, char data)
{
	i2c_start();
   	i2c_write(address);
   	i2c_write(data);
   	i2c_stop();
}

void main (void)
{
#asm
	movlw	0x80	; enable internal pull-ups and disable wake-up on pin change
	option
#endasm

	delay_ms(250);

	send_i2c (LM4970_ADR, LM4970_MODE);
	send_i2c (LM4970_ADR, LM4970_FREQ);
	if(!input(SW_TEST))
		send_i2c (LM4970_ADR, LM4970_PATTERN_TEST); // enable test mode
	else
		send_i2c (LM4970_ADR, LM4970_PATTERN);
	send_i2c (LM4970_ADR, LM4970_CURRENT);
	send_i2c (LM4970_ADR, LM4970_GAIN);

	sleep(); 	// sleepy time! our work is done...
}
